@@ -1,21 +1,23 @@
 adjCov <- function(x, id){
 
-cont2par <- c("N","GU","rGU","LO","LN","WEI","iG","GA","iGA")  
+cont2par <- c("N","GU","rGU","LO","LN","WEI","WEI2","iG","GA","iGA")  
+cont3par <- c("DAGUM")  
+
 
 Vb     <- x$Vb 
 
 if( x$margins[2]=="probit" && x$Model != "BPO0"){
 
 if(is.null(x$X3) )  mul <- 1
-if(!is.null(x$X3) ) mul <- x$X3[x$good,]
+if(!is.null(x$X3) ) mul <- x$X3
 
-scores <- cbind( c(x$fit$dl.dbe1)*x$X1[x$good,], c(x$fit$dl.dbe2)*x$X2[x$good,], c(x$fit$dl.drho)*mul )
+scores <- cbind( c(x$fit$dl.dbe1)*x$X1, c(x$fit$dl.dbe2)*x$X2, c(x$fit$dl.drho)*mul )
 
 }
 
 if( x$Model == "BPO0" ){
 
-scores <- cbind( c(x$fit$dl.dbe1)*x$X1[x$good,], c(x$fit$dl.dbe2)*x$X2[x$good,] )
+scores <- cbind( c(x$fit$dl.dbe1)*x$X1, c(x$fit$dl.dbe2)*x$X2 )
 
 }
 
@@ -23,8 +25,8 @@ scores <- cbind( c(x$fit$dl.dbe1)*x$X1[x$good,], c(x$fit$dl.dbe2)*x$X2[x$good,]
 
 if( x$margins[2] %in% cont2par ){
 
-if( !is.null(x$X3) && !is.null(x$X4) ) mul1 <- x$X3; mul2 <- x$X4 
-if(  is.null(x$X3) &&  is.null(x$X4) ) mul1 <- mul2 <- 1 
+if( !is.null(x$X3) && !is.null(x$X4) ) {mul1 <- x$X3; mul2 <- x$X4} 
+if(  is.null(x$X3) &&  is.null(x$X4) )  mul1 <- mul2 <- 1 
                                        
 scores <- cbind( c(x$fit$dl.dbe1)*x$X1, 
                  c(x$fit$dl.dbe2)*x$X2, 
@@ -32,6 +34,18 @@ scores <- cbind( c(x$fit$dl.dbe1)*x$X1,
                  c(x$fit$dl.dteta.st)*mul2       )                                           
 }
 
+if( x$margins[2] %in% cont3par ){
+
+if( !is.null(x$X3) && !is.null(x$X4) && !is.null(x$X5)) {mul1 <- x$X3; mul2 <- x$X4; mul3 <- x$X5} 
+if(  is.null(x$X3) &&  is.null(x$X4) &&  is.null(x$X5))  mul1 <- mul2 <- mul3 <- 1 
+                                       
+scores <- cbind( c(x$fit$dl.dbe1)*x$X1, 
+                 c(x$fit$dl.dbe2)*x$X2, 
+                 c(x$fit$dl.dsigma.st)*mul1,
+                 c(x$fit$dl.dnu.st)*mul2,
+                 c(x$fit$dl.dteta.st)*mul3       )                                           
+}
+
 
 
 
