@@ -1,6 +1,6 @@
 bprobgHs <- function(params, respvec, VC, sp = NULL, qu.mag = NULL, AT = FALSE){
 
-  X1 <- X2 <- X3 <- 1
+ 
   epsilon <- 0.0000001 # 0.9999999 0.0001 # sqrt(.Machine$double.eps)
   max.p   <- 0.9999999
 
@@ -16,33 +16,12 @@ bprobgHs <- function(params, respvec, VC, sp = NULL, qu.mag = NULL, AT = FALSE){
   p2 <- ifelse(p2 > max.p, max.p, p2) 
   p2 <- ifelse(p2 < epsilon, epsilon, p2) 
 
-  #criteria <- c(0,1)
-  #no.good <- apply(apply(cbind(p1,p2), c(1,2), `%in%`, criteria), 1, any)
-  #good <- no.good==FALSE
-  
-  good <- rep(TRUE,length(eta1))
 
-  p1 <- p1[good]
-  p2 <- p2[good]
-  d.n1 <- d.n1[good]
-  d.n2 <- d.n2[good]
-  eta1 <- eta1[good] 
-  eta2 <- eta2[good] 
-  X1 <- as.matrix(VC$X1[good,])
-  X2 <- as.matrix(VC$X2[good,])
-  if(!is.null(VC$X3)) X3 <- as.matrix(VC$X3[good,])   ## New bit
-  y1 <- respvec$y1[good]
-  y2 <- respvec$y2[good]
-  y1.y2 <- respvec$y1.y2[good]
-  y1.cy2 <- respvec$y1.cy2[good]
-  cy1.y2 <- respvec$cy1.y2[good]
-  cy1.cy2 <- respvec$cy1.cy2[good]
-  weights <- VC$weights[good]
   
   
 ######
   if(is.null(VC$X3))  teta.st <- params[(VC$X1.d2+VC$X2.d2+1)]
-  if(!is.null(VC$X3)) teta.st <- etad <- X3%*%params[(VC$X1.d2+VC$X2.d2+1):(VC$X1.d2+VC$X2.d2+VC$X3.d2)]
+  if(!is.null(VC$X3)) teta.st <- etad <- VC$X3%*%params[(VC$X1.d2+VC$X2.d2+1):(VC$X1.d2+VC$X2.d2+VC$X3.d2)]
 ######  
   
 
@@ -75,7 +54,7 @@ p11 <- pmax(BiCDF(p1, p2, VC$nC, teta), epsilon)
   p01 <- pmax(p2 - p11, epsilon)
   p00 <- pmax(1- p11 - p10 - p01, epsilon)
 
-  l.par <- weights*( y1.y2*log(p11)+y1.cy2*log(p10)+cy1.y2*log(p01)+cy1.cy2*log(p00) )
+  l.par <- VC$weights*( respvec$y1.y2*log(p11) + respvec$y1.cy2*log(p10) + respvec$cy1.y2*log(p01) + respvec$cy1.cy2*log(p00) )
 
 dH <- copgHs(p1,p2,eta1=NULL,eta2=NULL,teta,teta.st,VC$BivD)
 
@@ -121,18 +100,18 @@ bit2.th2 <- -bit1.th2
 bit3.th2 <- -bit1.th2 
 bit4.th2 <- bit1.th2 
 
-  dl.dbe1 <-  weights*d.n1*( (y1.y2*c.copula.be1/p11)  +
-                      (y1.cy2*(1-c.copula.be1)/p10) +
-                      (cy1.y2*c.copula.be1/(-p01)) +
-                      (cy1.cy2*(c.copula.be1-1)/p00) )
+  dl.dbe1 <-  VC$weights*d.n1*( (respvec$y1.y2*c.copula.be1/p11)  +
+                      (respvec$y1.cy2*(1-c.copula.be1)/p10) +
+                      (respvec$cy1.y2*c.copula.be1/(-p01)) +
+                      (respvec$cy1.cy2*(c.copula.be1-1)/p00) )
                                 
-  dl.dbe2 <-  weights*d.n2*( (y1.y2*c.copula.be2/p11)  +
-                            (y1.cy2*c.copula.be2/(-p10)) +
-                                (cy1.y2*(1-c.copula.be2)/(p01)) +
-                                (cy1.cy2*(c.copula.be2-1)/p00) )
+  dl.dbe2 <-  VC$weights*d.n2*( (respvec$y1.y2*c.copula.be2/p11)  +
+                            (respvec$y1.cy2*c.copula.be2/(-p10)) +
+                                (respvec$cy1.y2*(1-c.copula.be2)/(p01)) +
+                                (respvec$cy1.cy2*(c.copula.be2-1)/p00) )
 
-  dl.drho <- weights*( y1.y2*c.copula.theta/p11+y1.cy2*(-c.copula.theta)/p10 + 
-                       cy1.y2*(-c.copula.theta)/p01+cy1.cy2*c.copula.theta/p00 ) 
+  dl.drho <- VC$weights*( respvec$y1.y2*c.copula.theta/p11+respvec$y1.cy2*(-c.copula.theta)/p10 + 
+                       respvec$cy1.y2*(-c.copula.theta)/p01+respvec$cy1.cy2*c.copula.theta/p00 ) 
 
 
 add.b  <- 1
@@ -146,66 +125,66 @@ if(AT==TRUE){
 
 if(VC$hess==TRUE){
 
-  d2l.be1.be1  <- -weights*(y1.y2*(bit1.b1b1*p11-(c.copula.be1*d.n1)^2)/p11^2+
-                              y1.cy2*(bit2.b1b1*p10-((1-c.copula.be1)*d.n1)^2)/p10^2+
-                              cy1.y2*(bit3.b1b1*p01-(-c.copula.be1*d.n1)^2)/p01^2+
-                              cy1.cy2*(bit4.b1b1*p00-((c.copula.be1-1)*d.n1)^2)/p00^2 )
+  d2l.be1.be1  <- -VC$weights*(respvec$y1.y2*(bit1.b1b1*p11-(c.copula.be1*d.n1)^2)/p11^2+
+                              respvec$y1.cy2*(bit2.b1b1*p10-((1-c.copula.be1)*d.n1)^2)/p10^2+
+                              respvec$cy1.y2*(bit3.b1b1*p01-(-c.copula.be1*d.n1)^2)/p01^2+
+                              respvec$cy1.cy2*(bit4.b1b1*p00-((c.copula.be1-1)*d.n1)^2)/p00^2 )
 
-  d2l.be2.be2  <- -weights*(y1.y2*(bit1.b2b2*p11 - (c.copula.be2*d.n2)^2 )/p11^2+
-                              y1.cy2*(bit2.b2b2*p10-(-c.copula.be2*d.n2)^2)/p10^2+
-                              cy1.y2*(bit3.b2b2*p01- ((1-c.copula.be2)*d.n2)^2 )/p01^2+
-                              cy1.cy2*(bit4.b2b2*p00-((c.copula.be2-1)*d.n2)^2)/p00^2 )
+  d2l.be2.be2  <- -VC$weights*(respvec$y1.y2*(bit1.b2b2*p11 - (c.copula.be2*d.n2)^2 )/p11^2+
+                              respvec$y1.cy2*(bit2.b2b2*p10-(-c.copula.be2*d.n2)^2)/p10^2+
+                              respvec$cy1.y2*(bit3.b2b2*p01- ((1-c.copula.be2)*d.n2)^2 )/p01^2+
+                              respvec$cy1.cy2*(bit4.b2b2*p00-((c.copula.be2-1)*d.n2)^2)/p00^2 )
 
-  d2l.be1.be2  <- -weights*(y1.y2*(bit1.b1b2*p11-(c.copula.be1*d.n1*c.copula.be2*d.n2))/p11^2+
-                              y1.cy2*(bit2.b1b2*p10-((1-c.copula.be1)*d.n1)*(-c.copula.be2*d.n2))/p10^2+
-                              cy1.y2*(bit3.b1b2*p01-(-c.copula.be1*d.n1*(1-c.copula.be2)*d.n2))/p01^2+
-                              cy1.cy2*(bit4.b1b2*p00-((c.copula.be1-1)*d.n1*((c.copula.be2-1)*d.n2)))/p00^2 )
+  d2l.be1.be2  <- -VC$weights*(respvec$y1.y2*(bit1.b1b2*p11-(c.copula.be1*d.n1*c.copula.be2*d.n2))/p11^2+
+                              respvec$y1.cy2*(bit2.b1b2*p10-((1-c.copula.be1)*d.n1)*(-c.copula.be2*d.n2))/p10^2+
+                              respvec$cy1.y2*(bit3.b1b2*p01-(-c.copula.be1*d.n1*(1-c.copula.be2)*d.n2))/p01^2+
+                              respvec$cy1.cy2*(bit4.b1b2*p00-((c.copula.be1-1)*d.n1*((c.copula.be2-1)*d.n2)))/p00^2 )
 
-  d2l.be1.rho  <- -weights*(y1.y2*(bit1.b1th*p11-(c.copula.be1*d.n1*c.copula.theta))/p11^2+
-                              y1.cy2*(bit2.b1th*p10-((1-c.copula.be1)*d.n1)*(-c.copula.theta))/p10^2+
-                              cy1.y2*(bit3.b1th*p01-(-c.copula.be1*d.n1)*(-c.copula.theta))/p01^2+
-                              cy1.cy2*(bit4.b1th*p00-((c.copula.be1-1)*d.n1)*c.copula.theta)/p00^2 )/add.b
+  d2l.be1.rho  <- -VC$weights*(respvec$y1.y2*(bit1.b1th*p11-(c.copula.be1*d.n1*c.copula.theta))/p11^2+
+                              respvec$y1.cy2*(bit2.b1th*p10-((1-c.copula.be1)*d.n1)*(-c.copula.theta))/p10^2+
+                             respvec$cy1.y2*(bit3.b1th*p01-(-c.copula.be1*d.n1)*(-c.copula.theta))/p01^2+
+                              respvec$cy1.cy2*(bit4.b1th*p00-((c.copula.be1-1)*d.n1)*c.copula.theta)/p00^2 )/add.b
 
-  d2l.be2.rho  <- -weights*(y1.y2*(bit1.b2th*p11-(c.copula.be2*d.n2*c.copula.theta))/p11^2+
-                              y1.cy2*(bit2.b2th*p10-(-c.copula.be2*d.n2)*(-c.copula.theta))/p10^2+
-                              cy1.y2*(bit3.b2th*p01-((1-c.copula.be2)*d.n2)*(-c.copula.theta))/p01^2+
-                              cy1.cy2*(bit4.b2th*p00-((c.copula.be2-1)*d.n2)*c.copula.theta)/p00^2 )/add.b
+  d2l.be2.rho  <- -VC$weights*(respvec$y1.y2*(bit1.b2th*p11-(c.copula.be2*d.n2*c.copula.theta))/p11^2+
+                              respvec$y1.cy2*(bit2.b2th*p10-(-c.copula.be2*d.n2)*(-c.copula.theta))/p10^2+
+                             respvec$cy1.y2*(bit3.b2th*p01-((1-c.copula.be2)*d.n2)*(-c.copula.theta))/p01^2+
+                              respvec$cy1.cy2*(bit4.b2th*p00-((c.copula.be2-1)*d.n2)*c.copula.theta)/p00^2 )/add.b
                               
-  d2l.rho.rho  <- (-weights*(   y1.y2*(bit1.th2*p11-( c.copula.theta/add.b)^2)/p11^2+
-                               y1.cy2*(bit2.th2*p10-(-c.copula.theta/add.b)^2)/p10^2+
-                               cy1.y2*(bit3.th2*p01-(-c.copula.theta/add.b)^2)/p01^2+
-                              cy1.cy2*(bit4.th2*p00-( c.copula.theta/add.b)^2)/p00^2 ) )                            
+  d2l.rho.rho  <- (-VC$weights*(   respvec$y1.y2*(bit1.th2*p11-( c.copula.theta/add.b)^2)/p11^2+
+                               respvec$y1.cy2*(bit2.th2*p10-(-c.copula.theta/add.b)^2)/p10^2+
+                               respvec$cy1.y2*(bit3.th2*p01-(-c.copula.theta/add.b)^2)/p01^2+
+                              respvec$cy1.cy2*(bit4.th2*p00-( c.copula.theta/add.b)^2)/p00^2 ) )                            
 }     
 
 
 if(VC$hess==FALSE && VC$end==0){
 
-  d2l.be1.be1  <- -weights*(  (bit1.b1b1*p11-(c.copula.be1*d.n1)^2)/p11+
+  d2l.be1.be1  <- -VC$weights*(  (bit1.b1b1*p11-(c.copula.be1*d.n1)^2)/p11+
                               (bit2.b1b1*p10-((1-c.copula.be1)*d.n1)^2)/p10+
                               (bit3.b1b1*p01-(-c.copula.be1*d.n1)^2)/p01+
                               (bit4.b1b1*p00-((c.copula.be1-1)*d.n1)^2)/p00 )
 
-  d2l.be2.be2  <- -weights*((bit1.b2b2*p11 - (c.copula.be2*d.n2)^2 )/p11+
+  d2l.be2.be2  <- -VC$weights*((bit1.b2b2*p11 - (c.copula.be2*d.n2)^2 )/p11+
                               (bit2.b2b2*p10-(-c.copula.be2*d.n2)^2)/p10+
                               (bit3.b2b2*p01- ((1-c.copula.be2)*d.n2)^2 )/p01+
                               (bit4.b2b2*p00-((c.copula.be2-1)*d.n2)^2)/p00 )
 
-  d2l.be1.be2  <- -weights*((bit1.b1b2*p11-(c.copula.be1*d.n1*c.copula.be2*d.n2))/p11+
+  d2l.be1.be2  <- -VC$weights*((bit1.b1b2*p11-(c.copula.be1*d.n1*c.copula.be2*d.n2))/p11+
                               (bit2.b1b2*p10-((1-c.copula.be1)*d.n1)*(-c.copula.be2*d.n2))/p10+
                               (bit3.b1b2*p01-(-c.copula.be1*d.n1*(1-c.copula.be2)*d.n2))/p01+
                               (bit4.b1b2*p00-((c.copula.be1-1)*d.n1*((c.copula.be2-1)*d.n2)))/p00 )
 
-  d2l.be1.rho  <- -weights*((bit1.b1th*p11-(c.copula.be1*d.n1*c.copula.theta))/p11+
+  d2l.be1.rho  <- -VC$weights*((bit1.b1th*p11-(c.copula.be1*d.n1*c.copula.theta))/p11+
                               (bit2.b1th*p10-((1-c.copula.be1)*d.n1)*(-c.copula.theta))/p10+
                               (bit3.b1th*p01-(-c.copula.be1*d.n1)*(-c.copula.theta))/p01+
                               (bit4.b1th*p00-((c.copula.be1-1)*d.n1)*c.copula.theta)/p00 )/add.b
 
-  d2l.be2.rho  <- -weights*(  (bit1.b2th*p11-(c.copula.be2*d.n2*c.copula.theta))/p11+
+  d2l.be2.rho  <- -VC$weights*(  (bit1.b2th*p11-(c.copula.be2*d.n2*c.copula.theta))/p11+
                               (bit2.b2th*p10-(-c.copula.be2*d.n2)*(-c.copula.theta))/p10+
                               (bit3.b2th*p01-((1-c.copula.be2)*d.n2)*(-c.copula.theta))/p01+
                               (bit4.b2th*p00-((c.copula.be2-1)*d.n2)*c.copula.theta)/p00 )/add.b
 
-  d2l.rho.rho  <- -weights*(  (bit1.th2*p11-( c.copula.theta/add.b)^2)/p11+
+  d2l.rho.rho  <- -VC$weights*(  (bit1.th2*p11-( c.copula.theta/add.b)^2)/p11+
                               (bit2.th2*p10-(-c.copula.theta/add.b)^2)/p10+
                               (bit3.th2*p01-(-c.copula.theta/add.b)^2)/p01+
                               (bit4.th2*p00-( c.copula.theta/add.b)^2)/p00 )
@@ -220,10 +199,10 @@ se <- p10/p1
 th <- p01/(1-p1)
 fo <- p00/(1-p1)
 
-resp1 <- y1
-resp2 <- y1
-resp3 <- 1 - y1 
-resp4 <- 1 - y1 
+resp1 <- respvec$y1
+resp2 <- respvec$y1
+resp3 <- 1 - respvec$y1 
+resp4 <- 1 - respvec$y1 
 
 
 }
@@ -235,39 +214,39 @@ se <- p10/(1-p2)
 th <- p01/p2
 fo <- p00/(1-p2)
 
-resp1 <- y2
-resp2 <- 1 - y2
-resp3 <- y2 
-resp4 <- 1 - y2
+resp1 <- respvec$y2
+resp2 <- 1 - respvec$y2
+resp3 <- respvec$y2 
+resp4 <- 1 - respvec$y2
 
 }
 
-  d2l.be1.be1  <- -weights*(  fi*(bit1.b1b1*p11-(c.copula.be1*d.n1)^2)/p11^2*resp1+
+  d2l.be1.be1  <- -VC$weights*(  fi*(bit1.b1b1*p11-(c.copula.be1*d.n1)^2)/p11^2*resp1+
                               se*(bit2.b1b1*p10-((1-c.copula.be1)*d.n1)^2)/p10^2*resp2+
                               th*(bit3.b1b1*p01-(-c.copula.be1*d.n1)^2)/p01^2*resp3+
                               fo*(bit4.b1b1*p00-((c.copula.be1-1)*d.n1)^2)/p00^2*resp4 )
 
-  d2l.be2.be2  <- -weights*(  fi*(bit1.b2b2*p11 - (c.copula.be2*d.n2)^2 )/p11^2*resp1+
+  d2l.be2.be2  <- -VC$weights*(  fi*(bit1.b2b2*p11 - (c.copula.be2*d.n2)^2 )/p11^2*resp1+
                               se*(bit2.b2b2*p10-(-c.copula.be2*d.n2)^2)/p10^2*resp2+
                               th*(bit3.b2b2*p01- ((1-c.copula.be2)*d.n2)^2 )/p01^2*resp3+
                               fo*(bit4.b2b2*p00-((c.copula.be2-1)*d.n2)^2)/p00^2*resp4 )
 
-  d2l.be1.be2  <- -weights*(  fi*(bit1.b1b2*p11-(c.copula.be1*d.n1*c.copula.be2*d.n2))/p11^2*resp1+
+  d2l.be1.be2  <- -VC$weights*(  fi*(bit1.b1b2*p11-(c.copula.be1*d.n1*c.copula.be2*d.n2))/p11^2*resp1+
                               se*(bit2.b1b2*p10-((1-c.copula.be1)*d.n1)*(-c.copula.be2*d.n2))/p10^2*resp2+
                               th*(bit3.b1b2*p01-(-c.copula.be1*d.n1*(1-c.copula.be2)*d.n2))/p01^2*resp3+
                               fo*(bit4.b1b2*p00-((c.copula.be1-1)*d.n1*((c.copula.be2-1)*d.n2)))/p00^2*resp4 )
 
-  d2l.be1.rho  <- -weights*(  fi*(bit1.b1th*p11-(c.copula.be1*d.n1*c.copula.theta))/p11^2*resp1+
+  d2l.be1.rho  <- -VC$weights*(  fi*(bit1.b1th*p11-(c.copula.be1*d.n1*c.copula.theta))/p11^2*resp1+
                               se*(bit2.b1th*p10-((1-c.copula.be1)*d.n1)*(-c.copula.theta))/p10^2*resp2+
                               th*(bit3.b1th*p01-(-c.copula.be1*d.n1)*(-c.copula.theta))/p01^2*resp3+
                               fo*(bit4.b1th*p00-((c.copula.be1-1)*d.n1)*c.copula.theta)/p00^2*resp4 )/add.b
 
-  d2l.be2.rho  <- -weights*(  fi*(bit1.b2th*p11-(c.copula.be2*d.n2*c.copula.theta))/p11^2*resp1+
+  d2l.be2.rho  <- -VC$weights*(  fi*(bit1.b2th*p11-(c.copula.be2*d.n2*c.copula.theta))/p11^2*resp1+
                               se*(bit2.b2th*p10-(-c.copula.be2*d.n2)*(-c.copula.theta))/p10^2*resp2+
                               th*(bit3.b2th*p01-((1-c.copula.be2)*d.n2)*(-c.copula.theta))/p01^2*resp3+
                               fo*(bit4.b2th*p00-((c.copula.be2-1)*d.n2)*c.copula.theta)/p00^2*resp4 )/add.b
 
-  d2l.rho.rho  <- -weights*(  fi*(bit1.th2*p11-( c.copula.theta/add.b)^2)/p11^2*resp1+
+  d2l.rho.rho  <- -VC$weights*(  fi*(bit1.th2*p11-( c.copula.theta/add.b)^2)/p11^2*resp1+
                               se*(bit2.th2*p10-(-c.copula.theta/add.b)^2)/p10^2*resp2+
                               th*(bit3.th2*p01-(-c.copula.theta/add.b)^2)/p01^2*resp3+
                               fo*(bit4.th2*p00-( c.copula.theta/add.b)^2)/p00^2*resp4 )
@@ -278,11 +257,11 @@ resp4 <- 1 - y2
 
 if( is.null(VC$X3) ){
 
-  be1.be1 <- crossprod(X1*c(d2l.be1.be1),X1)
-  be2.be2 <- crossprod(X2*c(d2l.be2.be2),X2)
-  be1.be2 <- crossprod(X1*c(d2l.be1.be2),X2)
-  be1.rho <- t(t(rowSums(t(X1*c(d2l.be1.rho)))))
-  be2.rho <- t(t(rowSums(t(X2*c(d2l.be2.rho)))))
+  be1.be1 <- crossprod(VC$X1*c(d2l.be1.be1),VC$X1)
+  be2.be2 <- crossprod(VC$X2*c(d2l.be2.be2),VC$X2)
+  be1.be2 <- crossprod(VC$X1*c(d2l.be1.be2),VC$X2)
+  be1.rho <- t(t(rowSums(t(VC$X1*c(d2l.be1.rho)))))
+  be2.rho <- t(t(rowSums(t(VC$X2*c(d2l.be2.rho)))))
   
   H <- rbind( cbind( be1.be1    , be1.be2    , be1.rho ), 
               cbind( t(be1.be2) , be2.be2    , be2.rho ), 
@@ -291,20 +270,28 @@ if( is.null(VC$X3) ){
             
            
          
-         G   <- -c( colSums( c(dl.dbe1)*X1 ),
-                    colSums( c(dl.dbe2)*X2 ),
+         G   <- -c( colSums( c(dl.dbe1)*VC$X1 ),
+                    colSums( c(dl.dbe2)*VC$X2 ),
                     sum( dl.drho )  )
     
 }
 
 if( !is.null(VC$X3) ){
 
-  be1.be1 <- crossprod(X1*c(d2l.be1.be1),X1)
-  be2.be2 <- crossprod(X2*c(d2l.be2.be2),X2)
-  be1.be2 <- crossprod(X1*c(d2l.be1.be2),X2)
-  be1.rho <- crossprod(X1*c(d2l.be1.rho),X3)
-  be2.rho <- crossprod(X2*c(d2l.be2.rho),X3)
-  rho.rho <- crossprod(X3*c(d2l.rho.rho),X3)
+
+#nr <- 20000
+#nc <- 1000
+#X <- matrix(runif(nr*nc), nr, nc)
+#system.time(crossprod(X))
+#system.time(crossprod(X[1:(nr/2),]) + crossprod(X[(nr/2 + 1):nr,]))
+
+
+  be1.be1 <- crossprod(VC$X1*c(d2l.be1.be1),VC$X1)
+  be2.be2 <- crossprod(VC$X2*c(d2l.be2.be2),VC$X2)
+  be1.be2 <- crossprod(VC$X1*c(d2l.be1.be2),VC$X2)
+  be1.rho <- crossprod(VC$X1*c(d2l.be1.rho),VC$X3)
+  be2.rho <- crossprod(VC$X2*c(d2l.be2.rho),VC$X3)
+  rho.rho <- crossprod(VC$X3*c(d2l.rho.rho),VC$X3)
   
   H <- rbind( cbind( be1.be1    , be1.be2    , be1.rho ), 
               cbind( t(be1.be2) , be2.be2    , be2.rho ), 
@@ -312,9 +299,9 @@ if( !is.null(VC$X3) ){
             ) 
             
            
-         G   <- -c( colSums( c(dl.dbe1)*X1 ),
-                    colSums( c(dl.dbe2)*X2 ),
-                    colSums( c(dl.drho)*X3 )  )
+         G   <- -c( colSums( c(dl.dbe1)*VC$X1 ),
+                    colSums( c(dl.dbe2)*VC$X2 ),
+                    colSums( c(dl.drho)*VC$X3 )  )
     
 }
 
@@ -337,7 +324,7 @@ if(VC$extra.regI == "pC" && VC$hess==FALSE) H <- regH(H, type = 1)
 if(VC$extra.regI == "sED") H <- regH(H, type = 2) 
   
   
-rm(X1, X2, X3)  
+
   
 
          list(value=res, gradient=G, hessian=H, S.h=ps$S.h, l=S.res, l.par=l.par, ps = ps, 
@@ -345,7 +332,7 @@ rm(X1, X2, X3)
               dl.dbe1=dl.dbe1, dl.dbe2=dl.dbe2, dl.drho=dl.drho,
               d2l.be1.be1=d2l.be1.be1, d2l.be2.be2=d2l.be2.be2, 
               d2l.be1.be2=d2l.be1.be2, d2l.be1.rho=d2l.be1.rho,
-              d2l.be2.rho=d2l.be2.rho, d2l.rho.rho=d2l.rho.rho,good=good, 
+              d2l.be2.rho=d2l.be2.rho, d2l.rho.rho=d2l.rho.rho, 
               BivD=VC$BivD, p1=p1, p2=p2, theta.star = teta.st)      
 
 }
